@@ -30,10 +30,10 @@ lia_move int_branch::operator()() {
 }
 
 lia_move int_branch::create_branch_on_column(int j) {
-    TRACE("check_main_int", tout << "branching" << std::endl;);
+    TRACE(check_main_int, tout << "branching" << std::endl;);
     lia.get_term().clear();
 
-    lp_assert(j != -1);
+    SASSERT(j != -1);
     lia.get_term().add_monomial(mpq(1), j);
     if (lia.is_free(j)) {
         lia.is_upper() = lia.settings().random_next() % 2;
@@ -44,7 +44,7 @@ lia_move int_branch::create_branch_on_column(int j) {
         lia.offset() = lia.is_upper()? floor(lia.get_value(j)) : ceil(lia.get_value(j));        
     }
         
-    TRACE("int_solver",
+    TRACE(int_solver,
           lia.display_column(tout << "branching v" << j << " = " << lia.get_value(j) << "\n", j);
           tout << "k = " << lia.offset() << std::endl;);
     return lia_move::branch;        
@@ -62,7 +62,7 @@ int int_branch::find_inf_int_base_column() {
     mpq new_range;
     mpq small_value(1024);
     unsigned n = 0;
-    lar_core_solver & lcs = lra.m_mpq_lar_core_solver;
+    lar_core_solver & lcs = lra.get_core_solver();
     unsigned prev_usage = 0; // to quiet down the compiler
     unsigned k = 0;
     unsigned usage;
@@ -75,7 +75,7 @@ int int_branch::find_inf_int_base_column() {
         if (!lia.column_is_int_inf(j))
             continue;
         usage = lra.usage_in_terms(j);
-        if (lia.is_boxed(j) &&  (range = lcs.m_r_upper_bounds()[j].x - lcs.m_r_lower_bounds()[j].x - rational(2*usage)) <= small_value) {
+        if (lia.is_boxed(j) &&  (range = lcs.m_r_upper_bounds[j].x - lcs.m_r_lower_bounds[j].x - rational(2*usage)) <= small_value) {
             result = j;
             k++;            
             n = 1;
@@ -98,7 +98,7 @@ int int_branch::find_inf_int_base_column() {
             continue;
         SASSERT(!lia.is_fixed(j));
         usage = lra.usage_in_terms(j);
-        new_range  = lcs.m_r_upper_bounds()[j].x - lcs.m_r_lower_bounds()[j].x - rational(2*usage);
+        new_range  = lcs.m_r_upper_bounds[j].x - lcs.m_r_lower_bounds[j].x - rational(2*usage);
         if (new_range < range) {
             n = 1;
             result = j;
